﻿//---------------------------------------------------------------------------- 
//
//  Copyright (C) CSharp Labs.  All rights reserved.
// 
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
// 
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
// 
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.
// 
// History
//  06/13/13    Created 
//
//---------------------------------------------------------------------------

namespace System.IO
{
    /// <summary>
    /// Provides binary file reading and writing capability for classes.
    /// </summary>
    public interface IBinaryFile
    {
        #region Properties
        /// <summary>
        /// Gets the binary header.
        /// </summary>
        byte[] MagicNumber { get; }

        /// <summary>
        /// Gets the file version.
        /// </summary>
        int? Version { get; }

        /// <summary>
        /// Gets the minimum file version that can be loaded.
        /// </summary>
        int? MinimumVersion { get; }

        /// <summary>
        /// Gets the maximum file version that can be loaded.
        /// </summary>
        int? MaximumVersion { get; }
        #endregion

        #region Methods
        /// <summary>
        /// Handles reading binary data with a file version to create an object.
        /// </summary>
        /// <param name="reader">The <see cref="BinaryReader"/> to read data from.</param>
        /// <param name="version">The <see cref="BinaryFile"/> file version read from the underlying <see cref="Stream"/> or null if <see cref="BinaryFile.Version"/> is not implemented.</param>
        void Read(BinaryReader reader, int? version);

        /// <summary>
        /// Handles writing binary data.
        /// </summary>
        /// <param name="reader">The <see cref="BinaryWriter"/> to write data to.</param>
        void Write(BinaryWriter writer);
        #endregion
    }
}
